"""HTTP-specific constants for x402 protocol."""

# HTTP Header Names
PAYMENT_SIGNATURE_HEADER = "PAYMENT-SIGNATURE"
PAYMENT_REQUIRED_HEADER = "PAYMENT-REQUIRED"
PAYMENT_RESPONSE_HEADER = "PAYMENT-RESPONSE"
X_PAYMENT_HEADER = "X-PAYMENT"  # V1 legacy
X_PAYMENT_RESPONSE_HEADER = "X-PAYMENT-RESPONSE"  # V1 legacy
ACCESS_CONTROL_EXPOSE_HEADERS = "Access-Control-Expose-Headers"

# HTTP Status Codes
HTTP_STATUS_PAYMENT_REQUIRED = 402

# Default Facilitator URL
DEFAULT_FACILITATOR_URL = "https://x402.org/facilitator"
